@@ -6,7 +6,7 @@ use warnings;
 
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.007_02';
+our $VERSION   = '0.011_01';
 
 use Moo;
 use Type::Tiny::Role;
@@ -21,7 +21,6 @@ use Data::Dumper;
 use Carp;
 
 with 'Attean::API::TripleStore';
-with 'Attean::API::CostPlanner';
 with 'MooX::Log::Any';
 
 has 'endpoint_url' => (is => 'ro', isa => Uri, coerce => 1);
@@ -92,12 +91,6 @@ sub plans_for_algebra {
 	return;
 }
 
-sub cost_for_plan {
-	my $self = shift;
-	my $plan = shift;
-	return; #TODO for now
-}
-
 1;
 
 __END__
